@@ -1,16 +1,22 @@
 #' List to data frame.
-#' Reduce/simplify a list of homogenous objects to a data frame
+#' Reduce/simplify a list of homogenous objects to a data frame.
+#' All \code{NULL} entries are removed. Remaining entries must be all atomic
+#' or all data frames.
+#' 
 #' 
 #' @param res list of input data
 #' @param labels a data frame of labels, one row for each element of res
 #' @keywords internal
-list_to_dataframe <- function(res, labels = NULL) { 
+list_to_dataframe <- function(res, labels = NULL) {
+  res <- compact(res)
   if (length(res) == 0) return(data.frame())
-  
-  atomic <- unlist(llply(res, is.atomic))
+
+  atomic <- unlist(lapply(res, is.atomic))
+  df <- unlist(lapply(res, is.data.frame))
+
   if (all(atomic)) {
-    ulength <- unique(unlist(llply(res, length)))
-    if (length(ulength) != 1) stop("Results are not equal lengths")
+    ulength <- unique(unlist(lapply(res, length)))
+    if (length(ulength) != 1) stop("Results do not have equal lengths")
     
     if (length(res) > 1) {
       resdf <- as.data.frame(do.call("rbind", res), stringsAsFactors = FALSE)
@@ -18,11 +24,11 @@ list_to_dataframe <- function(res, labels = NULL) {
       resdf <- as.data.frame(res[[1]], stringsAsFactors = FALSE)
     }
     rows <- rep(1, length(res))
-  } else {
-    l_ply(res, function(x) if(!is.null(x) & !is.data.frame(x)) stop("Not a data.frame!"))
-
+  } else if (all(df)) {
     resdf <- rbind.fill(res)
-    rows <- unlist(llply(res, function(x) if(is.null(x)) 0 else nrow(x)))
+    rows <- unlist(lapply(res, NROW))
+  } else {
+    stop("Results must be all atomic, or all data frames")
   }
 
   # If no labels supplied, use list names
